summaryrefslogtreecommitdiffstats
path: root/kdesktop/bgmanager.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kdesktop/bgmanager.cc')
-rw-r--r--kdesktop/bgmanager.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdesktop/bgmanager.cc b/kdesktop/bgmanager.cc
index cf61030bb..a643905eb 100644
--- a/kdesktop/bgmanager.cc
+++ b/kdesktop/bgmanager.cc
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
{
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
// Qt eats repaint events in this case :-((
sv->viewport()->update();
}
m_pDesktop->setErasePixmap(*ep);
- m_pDesktop->repaint();
+ m_pDesktop->tqrepaint();
static bool root_cleared = false;
if( !root_cleared )
{ // clear the root window pixmap set by kdm
@@ -923,7 +923,7 @@ void KBackgroundManager::setWallpaper(int desk, TQString wallpaper, int mode)
void KBackgroundManager::repaintBackground()
{
if (m_pDesktop)
- m_pDesktop->repaint();
+ m_pDesktop->tqrepaint();
else
TQT_TQWIDGET(KApplication::desktop()->screen())->erase();
}
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
- // Qt eats repaint events in this case :-((
+ // Qt eats tqrepaint events in this case :-((
sv->viewport()->update();
}